import network
import espnow
import machine
import ujson
import time
from machine import I2C, Pin
from ssd1306 import SSD1306_I2C
import struct

# A WLAN interface must be active to send()/recv()
sta = network.WLAN(network.STA_IF)  # Or network.AP_IF
sta.active(True)
sta.disconnect()      # For ESP8266

device_mac = sta.config('mac')
print("Device MAC Address:", ':'.join(['{:02x}'.format(b) for b in device_mac]))

# Initialize ESP-NOW
esp = espnow.ESPNow()
esp.active(True)

device_1_mac = b'\x48\x55\x19\xC8\x02\x7F'  # Replace with Device 1 MAC address
device_2_mac = b'\xC8\x2B\x96\x08\x9A\x70'  # Replace with Device 2 MAC address

# Set peer MAC address based on the current device
if device_mac == device_1_mac:
    peer_mac = device_2_mac
    device_name = "Device 1"
    role = "Player1"
else:
    peer_mac = device_1_mac
    device_name = "Device 2"
    role = "Player2"
    
esp.add_peer(peer_mac)

i2c = I2C(scl=Pin(5), sda=Pin(4))  # GPIO 5 (D1) = SCL, GPIO 4 (D2) = SDA
oled = SSD1306_I2C(128, 64, i2c)   # 128x64 resolution

up = machine.Pin(14, machine.Pin.IN,machine.Pin.PULL_UP)
down = machine.Pin(2, machine.Pin.IN,machine.Pin.PULL_UP)
reset = machine.Pin(12, machine.Pin.IN,machine.Pin.PULL_UP)


paddle1Y = 20
paddle2Y = 20# Pozycja paletki gracza 2
ballx = 64 
bally = 1

# Funkcje sterujące paletką
def move_paddle(paddle, direction):
    global paddle1Y, paddle2Y
    if paddle == "paddle1Y":
        if direction == "up" and paddle1Y > 0:
            paddle1Y -= 5
        elif direction == "down" and paddle1Y < 50:
            paddle1Y += 5
    elif paddle == "paddle2Y":
        if direction == "up" and paddle2Y > 0:
            paddle2Y -= 5
        elif direction == "down" and paddle2Y < 50:
            paddle2Y += 5
            
            
def display_game():
    oled.fill(0)  # Wyczyść ekran
    oled.line(10, paddle1Y ,10, paddle1Y+14 ,1)  # Paletka gracza 1
    oled.line(118, paddle2Y ,118,paddle2Y+14 ,1)  # Paletka gracza 2
    oled.show()

while True:

    
    if up.value() == 0:  # Gdy przycisk "góra" jest wciśnięty
        if role == "Player1":
            move_paddle("paddle1Y", "up")
        else:
            move_paddle("paddle2Y", "up")
       
    if down.value() == 0:  # Gdy przycisk "dół" jest wciśnięty
        if role == "Player1":
            move_paddle("paddle1Y", "down")
        else:
            move_paddle("paddle2Y", "down")  


    
    _, msg = esp.recv()
    if msg:
         paddle1Y = int.from_bytes(msg[0:2], 'little')  # Pierwsze 4 bajty
         ballx = int.from_bytes(msg[2:4], 'little')
         bally = int.from_bytes(msg[4:6], 'little')
         gracz1 = int.from_bytes(msg[6:8], 'little')
         gracz2 = int.from_bytes(msg[8:10], 'little')
         znacznik = int.from_bytes(msg[10:12], 'little')
         
    if znacznik ==1:
        paddle2Y = 20
        
    message = bytearray()
    message.extend(paddle2Y.to_bytes(2, 'little'))
    esp.send(peer_mac, message)
    

    
    oled.fill(0)  # Wyczyść ekran
    oled.line(10, paddle1Y,10, paddle1Y+14 ,1)  # Paletka gracza 1
    oled.line(118, paddle2Y,118,paddle2Y+14 ,1)  # Paletka gracza 2
    oled.pixel(ballx, bally,1)
    oled.text(f'{gracz1}:{gracz2}*',50,2)
    oled.show()
    
    if ballx <=0 or ballx>=127:
        paddle2Y = 20
    
#     oled.fill(0)  # Czyszczenie ekranu OLED
#     oled.text("Gracz 1:", 0, 0)
#     oled.text(f"Liczba: {paddle1Y}", 0, 10)
#     
#     oled.text("Gracz 2:", 0, 30)
#     oled.text(f"Liczba: {paddle2Y}", 0, 40)
#     oled.show()

    time.sleep(0.05)  # Opóźnienie